@@ -232,7 +232,7 @@ def cases(request, product, testID):
     sheet = "Context"
     xlsx_path_app = "././conf/app/" + product + '/' + name
     xlsx_path_web = "././conf/web/" + product + '/' + name
-    xlsx_path_rwd = "././conf/rwd" + product + '/' + name
+    xlsx_path_rwd = "././conf/rwd/" + product + '/' + name
 
     if os.path.exists(xlsx_path_app):
         file_path = xlsx_path_app
